pub struct EventAttribute {
pub key: String,
pub value: String,
pub index: bool,
}Expand description
A key-value pair describing an Event.
Generic methods are provided for more ergonomic attribute construction, see
Event::new for details.
Fields
key: StringThe event key.
value: StringThe event value.
index: boolWhether Tendermint’s indexer should index this event.
This field is nondeterministic.
Implementations
Sourceimpl EventAttribute
impl EventAttribute
Sourcepub fn eq_ignoring_index(&self, other: &Self) -> bool
pub fn eq_ignoring_index(&self, other: &Self) -> bool
Checks whether &self is equal to other, ignoring the index field.
Sourcepub fn hash_ignoring_index<H: Hasher>(&self, state: &mut H)
pub fn hash_ignoring_index<H: Hasher>(&self, state: &mut H)
A variant of core::hash::Hash::hash that ignores the index field.